==> lxqt-session-2.0.0.tar.xz: lxqt-session-2.0.0/lxqt-config-session/translations/lxqt-config-session_lg.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lg">
<context>
    <name>AutoStartEdit</name>
    <message>
        <location filename="../autostartedit.ui" line="14"/>
        <source>Edit</source>
        <translation>Kyusa</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="20"/>
        <source>Name:</source>
        <translation>Linnya:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="27"/>
        <source>Search...</source>
        <translation>Noonya...</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="47"/>
        <source>Command:</source>
        <translation>Kiragiro:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="57"/>
        <source>Wait for system tray</source>
        <translation>Kirinde akakuŋaanyizo kamale okutandika</translation>
    </message>
    <message>
        <location filename="../autostartedit.cpp" line="61"/>
        <source>Select Application</source>
        <translation>Londa puloguramu</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <location filename="../autostartmodel.cpp" line="193"/>
        <source>Global Autostart</source>
        <translation>Ebitandikirawo mu biteekateeka awakolerwa byonna</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="195"/>
        <source>LXQt Autostart</source>
        <translation>Ebitandikirawo mu LXQt mwokka</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="213"/>
        <source>Location: %1</source>
        <translation>Obusangiro: %1</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="215"/>
        <source>Overrides: %1</source>
        <translation>Kidda mu kifo kya: %1</translation>
    </message>
</context>
<context>
    <name>AutoStartPage</name>
    <message>
        <location filename="../autostartpage.ui" line="17"/>
        <source>Delete</source>
        <translation>Gyawo</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="24"/>
        <source>Add</source>
        <translation>Yongerawo</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="31"/>
        <source>Edit</source>
        <translation>Kyusa</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="44"/>
        <source>Application Autostart</source>
        <translation>Puloguramu ezitandikirawo</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="138"/>
        <location filename="../autostartpage.cpp" line="147"/>
        <location filename="../autostartpage.cpp" line="161"/>
        <location filename="../autostartpage.cpp" line="174"/>
        <source>Error</source>
        <translation>Kiremya</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="138"/>
        <location filename="../autostartpage.cpp" line="161"/>
        <source>Please provide Name and Command</source>
        <translation>Teekawo ekiragiro n&apos;okunnyonyola</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="147"/>
        <location filename="../autostartpage.cpp" line="174"/>
        <source>File &apos;%1&apos; already exists!</source>
        <translation>Waliwo fayiro &apos;%1&apos; esangidwawo!</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Enteekateeka ez&apos;awamu</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Window Manager</source>
        <translation>Ekiteekateekamadirisa</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <source>Search...</source>
        <translation>Noonya...</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="59"/>
        <source>LXQt Modules</source>
        <translation>Enyingo za LXQt</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="65"/>
        <source>Start</source>
        <translation>Tandika</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="72"/>
        <source>Stop</source>
        <translation>Komya</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="111"/>
        <source>Global Screen Scaling</source>
        <translation>Obunene bw&apos;ebirabikira ku lutimbe</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="123"/>
        <source>Scale factor:</source>
        <translation>Ekigero ky&apos;obunene:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="149"/>
        <source>Leave Session</source>
        <translation>Okukomya olutuula</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="155"/>
        <source>Ask for confirmation to leave session</source>
        <translation>Okulukomya malanga okukakasa</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="162"/>
        <source>Lock screen before suspending/hibernating</source>
        <translation>Kompyuta nga en&apos;erindisibwa oba okwebasibwa olutimbe lusaanikirwe</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="169"/>
        <source>Suspend/hibernate after lock delay:</source>
        <translation>Okulindisa oba okwebasa kutandika nga olutimbe lusaanikiridwa:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="182"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="176"/>
        <source>Select a window manager</source>
        <translation>Londa ekiteekateekamadirisa</translation>
    </message>
</context>
<context>
    <name>EnvironmentPage</name>
    <message>
        <location filename="../environmentpage.ui" line="17"/>
        <source>Add</source>
        <translation>Yongerawo</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="24"/>
        <source>Delete</source>
        <translation>Gyawo</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="50"/>
        <source>Environment Variables (Advanced)</source>
        <translation>Bigambo bya mu nviromenti (byetaagisa bumanyirivu)</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="61"/>
        <source>Variable Name</source>
        <translation>Kigambo</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="66"/>
        <source>Value</source>
        <translation>Kye kikongojja</translation>
    </message>
</context>
<context>
    <name>ModuleModel</name>
    <message>
        <location filename="../modulemodel.cpp" line="87"/>
        <source>Running</source>
        <translation>Etandikidwa</translation>
    </message>
</context>
<context>
    <name>SessionConfigWindow</name>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="44"/>
        <source>LXQt Session Settings</source>
        <translation>Enteekateeka z&apos;entuula za LXQt</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="47"/>
        <source>Basic Settings</source>
        <translation>Enteekateeka ez&apos;awamu</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="53"/>
        <source>User Directories</source>
        <translation>Materekero ez&apos;omu akawunti</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="59"/>
        <source>Autostart</source>
        <translation>Ebitandikirawo</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="65"/>
        <source>Environment (Advanced)</source>
        <translation>Nviromenti (kyetaagisa bumanyirivu)</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="91"/>
        <source>Session Restart Required</source>
        <translation>Kyetaagisa kuddamu okutandika olutuula</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="92"/>
        <source>Some settings will not take effect until the next log in.</source>
        <translation>Enkyukakyuka ezimu okulabika kyetaagisa okuddamu kutandika olutuula.</translation>
    </message>
</context>
<context>
    <name>UserLocationsPage</name>
    <message>
        <location filename="../userlocationspage.cpp" line="116"/>
        <source>Locations for Personal Files</source>
        <translation>Obusangiro bwa fayiro zo</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="184"/>
        <source>LXQt Session Settings - User Directories</source>
        <translation>Nteekateeka z&apos;entuula za LXQt Materekero ga mu akawunti</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="185"/>
        <source>An error occurred while applying the settings for the %1 location</source>
        <translation>Wazzewo kiremya mu kutegeka obusangiro bwa %1</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="201"/>
        <source>Choose Location</source>
        <translation>Londa obusangiro</translation>
    </message>
</context>
<context>
    <name>UserLocationsPrivate</name>
    <message>
        <location filename="../userlocationspage.cpp" line="63"/>
        <source>Desktop</source>
        <translation>Awakolerwa</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="64"/>
        <source>Downloads</source>
        <translation>Ebiwanudwa</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="65"/>
        <source>Templates</source>
        <translation>Entiba</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="66"/>
        <source>Public Share</source>
        <translation>Ebikkirizibwamu bonna</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="67"/>
        <source>Documents</source>
        <translation>Ebiwandike</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="68"/>
        <source>Music</source>
        <translation>Enyimba</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="69"/>
        <source>Pictures</source>
        <translation>Bifaananyi</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="70"/>
        <source>Videos</source>
        <translation>Vidiyo</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="73"/>
        <source>Contains all the files which you see on your desktop</source>
        <translation>Fayiro zonna z&apos;olaba awakolerwa wano wezisangibwa</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="74"/>
        <source>Default folder to save your downloaded files</source>
        <translation>By&apos;owanula bigenda wano mu bya bulijjo</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="75"/>
        <source>Default folder to load or save templates from or to</source>
        <translation>Entiba za fayiro mu bya bulijjo zinonebwa wano era ne z&apos;okolawo weziterekebwa</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="76"/>
        <source>Default folder to publicly share your files</source>
        <translation>Mu bya bulijjo by&apos;oyagala abalala basobole okukolako obuteeka wano</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="77"/>
        <source>Default folder to load or save documents from or to</source>
        <translation>Mu bya bulijjo wano w&apos;oteeka ebiwandike byo</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="78"/>
        <source>Default folder to load or save music from or to</source>
        <translation>Mu bya bulijjo wano w&apos;oteeka fayiro zo ez&apos;ebiwulirizibwa</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="79"/>
        <source>Default folder to load or save pictures from or to</source>
        <translation>Mu bya bulijjo wano w&apos;oteeka ebifaananyi byo</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="80"/>
        <source>Default folder to load or save videos from or to</source>
        <translation>Mu bya bulijjo wano w&apos;oteeka vidiyo zo</translation>
    </message>
</context>
</TS>

==> lxqt-session_2.1.1.orig.tar.xz: lxqt-session-2.1.1/lxqt-config-session/translations/lxqt-config-session_lg.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lg">
<context>
    <name>AutoStartEdit</name>
    <message>
        <location filename="../autostartedit.ui" line="14"/>
        <source>Edit</source>
        <translation>Kyusa</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="20"/>
        <source>Name:</source>
        <translation>Linnya:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="40"/>
        <source>Search...</source>
        <translation>Noonya...</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="54"/>
        <source>Start only in X11</source>
        <translation>Tandika nga X11 y&apos;ekola</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="30"/>
        <source>Command:</source>
        <translation>Kiragiro:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="47"/>
        <source>Wait for system tray</source>
        <translation>Kirinde akakuŋaanyizo kamale okutandika</translation>
    </message>
    <message>
        <location filename="../autostartedit.cpp" line="67"/>
        <source>Select Application</source>
        <translation>Londa puloguramu</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <location filename="../autostartmodel.cpp" line="193"/>
        <source>Global Autostart</source>
        <translation>Ebitandikirawo mu biteekateeka awakolerwa byonna</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="195"/>
        <source>LXQt Autostart</source>
        <translation>Ebitandikirawo mu LXQt mwokka</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="213"/>
        <source>Location: %1</source>
        <translation>Obusangiro: %1</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="215"/>
        <source>Overrides: %1</source>
        <translation>Kidda mu kifo kya: %1</translation>
    </message>
</context>
<context>
    <name>AutoStartPage</name>
    <message>
        <location filename="../autostartpage.ui" line="17"/>
        <source>Delete</source>
        <translation>Gyawo</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="24"/>
        <source>Add</source>
        <translation>Yongerawo</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="31"/>
        <source>Edit</source>
        <translation>Kyusa</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="44"/>
        <source>Application Autostart</source>
        <translation>Puloguramu ezitandikirawo</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="140"/>
        <location filename="../autostartpage.cpp" line="151"/>
        <location filename="../autostartpage.cpp" line="170"/>
        <location filename="../autostartpage.cpp" line="187"/>
        <source>Error</source>
        <translation>Kiremya</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="140"/>
        <location filename="../autostartpage.cpp" line="170"/>
        <source>Please provide Name and Command</source>
        <translation>Teekawo ekiragiro n&apos;okunnyonyola</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="151"/>
        <location filename="../autostartpage.cpp" line="187"/>
        <source>File &apos;%1&apos; already exists!</source>
        <translation>Waliwo fayiro &apos;%1&apos; esangidwawo!</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Enteekateeka ez&apos;awamu</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Window Manager</source>
        <translation>Ekiteekateekamadirisa</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <source>Search...</source>
        <translation>Noonya...</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="59"/>
        <source>LXQt Modules</source>
        <translation>Enyingo za LXQt</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="65"/>
        <source>Start</source>
        <translation>Tandika</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="72"/>
        <source>Stop</source>
        <translation>Komya</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="111"/>
        <source>Under Wayland, adjust scaling via compositor settings or kanshi instead.</source>
        <translation>Wayland bw&apos;eba nga y&apos;ekola, obunene bw&apos;ebirabika bugoberere enteekateeka z&apos;ekikwanaganya ebirabikira awakolerwa oba eza kanshi.</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="114"/>
        <source>Global Screen Scaling</source>
        <translation>Obunene bw&apos;ebirabikira ku lutimbe</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="126"/>
        <source>Scale factor:</source>
        <translation>Ekigero ky&apos;obunene:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="152"/>
        <source>Leave Session</source>
        <translation>Okukomya olutuula</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="158"/>
        <source>Ask for confirmation to leave session</source>
        <translation>Okulukomya malanga okukakasa</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="165"/>
        <source>Lock screen before suspending/hibernating</source>
        <translation>Kompyuta nga en&apos;erindisibwa oba okwebasibwa olutimbe lusaanikirwe</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="172"/>
        <source>Suspend/hibernate after lock delay:</source>
        <translation>Okulindisa oba okwebasa kutandika nga olutimbe lusaanikiridwa:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="185"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="176"/>
        <source>Select a window manager</source>
        <translation>Londa ekiteekateekamadirisa</translation>
    </message>
</context>
<context>
    <name>EnvironmentPage</name>
    <message>
        <location filename="../environmentpage.ui" line="17"/>
        <source>Add</source>
        <translation>Yongerawo</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="24"/>
        <source>Delete</source>
        <translation>Gyawo</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="50"/>
        <source>Environment Variables (Advanced)</source>
        <translation>Bigambo bya mu nviromenti (byetaagisa bumanyirivu)</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="61"/>
        <source>Variable Name</source>
        <translation>Kigambo</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="66"/>
        <source>Value</source>
        <translation>Kye kikongojja</translation>
    </message>
</context>
<context>
    <name>ModuleModel</name>
    <message>
        <location filename="../modulemodel.cpp" line="87"/>
        <source>Running</source>
        <translation>Etandikidwa</translation>
    </message>
</context>
<context>
    <name>SessionConfigWindow</name>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="45"/>
        <source>LXQt Session Settings</source>
        <translation>Enteekateeka z&apos;entuula za LXQt</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="48"/>
        <source>Basic Settings</source>
        <translation>Enteekateeka ez&apos;awamu</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="54"/>
        <source>User Directories</source>
        <translation>Materekero ez&apos;omu akawunti</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="60"/>
        <source>Autostart</source>
        <translation>Ebitandikirawo</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="67"/>
        <source>Wayland Settings (Experimental)</source>
        <translation>Enteekateeka za Wayland (Kikyagezesebwa)</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="74"/>
        <source>Environment (Advanced)</source>
        <translation>Nviromenti (kyetaagisa bumanyirivu)</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="100"/>
        <source>Session Restart Required</source>
        <translation>Kyetaagisa kuddamu okutandika olutuula</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="101"/>
        <source>Some settings will not take effect until the next log in.</source>
        <translation>Enkyukakyuka ezimu okulabika kyetaagisa okuddamu kutandika olutuula.</translation>
    </message>
</context>
<context>
    <name>UserLocationsPage</name>
    <message>
        <location filename="../userlocationspage.cpp" line="116"/>
        <source>Locations for Personal Files</source>
        <translation>Obusangiro bwa fayiro zo</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="184"/>
        <source>LXQt Session Settings - User Directories</source>
        <translation>Nteekateeka z&apos;entuula za LXQt Materekero ga mu akawunti</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="185"/>
        <source>An error occurred while applying the settings for the %1 location</source>
        <translation>Wazzewo kiremya mu kutegeka obusangiro bwa %1</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="201"/>
        <source>Choose Location</source>
        <translation>Londa obusangiro</translation>
    </message>
</context>
<context>
    <name>UserLocationsPrivate</name>
    <message>
        <location filename="../userlocationspage.cpp" line="63"/>
        <source>Desktop</source>
        <translation>Awakolerwa</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="64"/>
        <source>Downloads</source>
        <translation>Ebiwanudwa</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="65"/>
        <source>Templates</source>
        <translation>Entiba</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="66"/>
        <source>Public Share</source>
        <translation>Ebikkirizibwamu bonna</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="67"/>
        <source>Documents</source>
        <translation>Ebiwandike</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="68"/>
        <source>Music</source>
        <translation>Enyimba</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="69"/>
        <source>Pictures</source>
        <translation>Bifaananyi</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="70"/>
        <source>Videos</source>
        <translation>Vidiyo</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="73"/>
        <source>Contains all the files which you see on your desktop</source>
        <translation>Fayiro zonna z&apos;olaba awakolerwa wano wezisangibwa</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="74"/>
        <source>Default folder to save your downloaded files</source>
        <translation>By&apos;owanula bigenda wano mu bya bulijjo</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="75"/>
        <source>Default folder to load or save templates from or to</source>
        <translation>Entiba za fayiro mu bya bulijjo zinonebwa wano era ne z&apos;okolawo weziterekebwa</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="76"/>
        <source>Default folder to publicly share your files</source>
        <translation>Mu bya bulijjo by&apos;oyagala abalala basobole okukolako obuteeka wano</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="77"/>
        <source>Default folder to load or save documents from or to</source>
        <translation>Mu bya bulijjo wano w&apos;oteeka ebiwandike byo</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="78"/>
        <source>Default folder to load or save music from or to</source>
        <translation>Mu bya bulijjo wano w&apos;oteeka fayiro zo ez&apos;ebiwulirizibwa</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="79"/>
        <source>Default folder to load or save pictures from or to</source>
        <translation>Mu bya bulijjo wano w&apos;oteeka ebifaananyi byo</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="80"/>
        <source>Default folder to load or save videos from or to</source>
        <translation>Mu bya bulijjo wano w&apos;oteeka vidiyo zo</translation>
    </message>
</context>
<context>
    <name>WaylandSettings</name>
    <message>
        <location filename="../waylandsettings.ui" line="23"/>
        <source>Wayland Settings</source>
        <translation>Nteekateeka za Wayland</translation>
    </message>
    <message>
        <location filename="../waylandsettings.ui" line="30"/>
        <source>Wayland compositor:</source>
        <translation>Puloguramu enaakawanaganyanga ebirabikira awakolerwa nga Wayland y&apos;ekola:</translation>
    </message>
    <message>
        <location filename="../waylandsettings.ui" line="49"/>
        <location filename="../waylandsettings.ui" line="81"/>
        <source>Search...</source>
        <translation>Noonya...</translation>
    </message>
    <message>
        <location filename="../waylandsettings.ui" line="59"/>
        <source>Screenlock command:</source>
        <translation>Ekiragiro ekikisa awakolerwa:</translation>
    </message>
    <message>
        <location filename="../waylandsettings.ui" line="71"/>
        <source>Use &quot;loginctl lock-session&quot; on kwin_wayland</source>
        <translation>kwin_wayland bw&apos;eba nga y&apos;ekola kozesa &quot;loginctl lock-session&quot;</translation>
    </message>
    <message>
        <location filename="../waylandsettings.cpp" line="98"/>
        <source>Select a Wayland Compositor</source>
        <translation>Londa puloguramu enaakwanaganyanga ebirabikira awakolerwa Wayland nga y&apos;ekola</translation>
    </message>
    <message>
        <location filename="../waylandsettings.cpp" line="103"/>
        <source>Select a Screenlocker for Wayland</source>
        <translation>Londa puloguramu ekisa awakolerwa Wayland nga y&apos;ekola</translation>
    </message>
</context>
</TS>
